==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/FactoryGitHubConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.FactoryGitHubConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Factory's GitHub repo information.
 * @property accountName Account name.
 * @property clientId GitHub bring your own app client id.
 * @property clientSecret GitHub bring your own app client secret information.
 * @property collaborationBranch Collaboration branch.
 * @property disablePublish Disable manual publish operation in ADF studio to favor automated publish.
 * @property hostName GitHub Enterprise host name. For example: `https://github.mydomain.com`
 * @property lastCommitId Last commit id.
 * @property repositoryName Repository name.
 * @property rootFolder Root folder.
 * @property type Type of repo configuration.
 * Expected value is 'FactoryGitHubConfiguration'.
 */
public data class FactoryGitHubConfigurationArgs(
    public val accountName: Output<String>,
    public val clientId: Output<String>? = null,
    public val clientSecret: Output<GitHubClientSecretArgs>? = null,
    public val collaborationBranch: Output<String>,
    public val disablePublish: Output<Boolean>? = null,
    public val hostName: Output<String>? = null,
    public val lastCommitId: Output<String>? = null,
    public val repositoryName: Output<String>,
    public val rootFolder: Output<String>,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.FactoryGitHubConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.FactoryGitHubConfigurationArgs =
        com.pulumi.azurenative.datafactory.inputs.FactoryGitHubConfigurationArgs.builder()
            .accountName(accountName.applyValue({ args0 -> args0 }))
            .clientId(clientId?.applyValue({ args0 -> args0 }))
            .clientSecret(clientSecret?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .collaborationBranch(collaborationBranch.applyValue({ args0 -> args0 }))
            .disablePublish(disablePublish?.applyValue({ args0 -> args0 }))
            .hostName(hostName?.applyValue({ args0 -> args0 }))
            .lastCommitId(lastCommitId?.applyValue({ args0 -> args0 }))
            .repositoryName(repositoryName.applyValue({ args0 -> args0 }))
            .rootFolder(rootFolder.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [FactoryGitHubConfigurationArgs].
 */
@PulumiTagMarker
public class FactoryGitHubConfigurationArgsBuilder internal constructor() {
    private var accountName: Output<String>? = null

    private var clientId: Output<String>? = null

    private var clientSecret: Output<GitHubClientSecretArgs>? = null

    private var collaborationBranch: Output<String>? = null

    private var disablePublish: Output<Boolean>? = null

    private var hostName: Output<String>? = null

    private var lastCommitId: Output<String>? = null

    private var repositoryName: Output<String>? = null

    private var rootFolder: Output<String>? = null

    private var type: Output<String>? = null

    /**
     * @param value Account name.
     */
    @JvmName("nqwcuencdaimdqco")
    public suspend fun accountName(`value`: Output<String>) {
        this.accountName = value
    }

    /**
     * @param value GitHub bring your own app client id.
     */
    @JvmName("bimvbdfovcvawqig")
    public suspend fun clientId(`value`: Output<String>) {
        this.clientId = value
    }

    /**
     * @param value GitHub bring your own app client secret information.
     */
    @JvmName("laigpiqlbmcesvrv")
    public suspend fun clientSecret(`value`: Output<GitHubClientSecretArgs>) {
        this.clientSecret = value
    }

    /**
     * @param value Collaboration branch.
     */
    @JvmName("sfueusggafewrfra")
    public suspend fun collaborationBranch(`value`: Output<String>) {
        this.collaborationBranch = value
    }

    /**
     * @param value Disable manual publish operation in ADF studio to favor automated publish.
     */
    @JvmName("kmvvapepwbiowwyx")
    public suspend fun disablePublish(`value`: Output<Boolean>) {
        this.disablePublish = value
    }

    /**
     * @param value GitHub Enterprise host name. For example: `https://github.mydomain.com`
     */
    @JvmName("utxvgytpsqcljsej")
    public suspend fun hostName(`value`: Output<String>) {
        this.hostName = value
    }

    /**
     * @param value Last commit id.
     */
    @JvmName("vgsmdqnioltokgep")
    public suspend fun lastCommitId(`value`: Output<String>) {
        this.lastCommitId = value
    }

    /**
     * @param value Repository name.
     */
    @JvmName("aofmourbmuautlhf")
    public suspend fun repositoryName(`value`: Output<String>) {
        this.repositoryName = value
    }

    /**
     * @param value Root folder.
     */
    @JvmName("mpujrmadkslygwgv")
    public suspend fun rootFolder(`value`: Output<String>) {
        this.rootFolder = value
    }

    /**
     * @param value Type of repo configuration.
     * Expected value is 'FactoryGitHubConfiguration'.
     */
    @JvmName("wusqfokqrqdugwrv")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Account name.
     */
    @JvmName("vboxsmljqqtcibbg")
    public suspend fun accountName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.accountName = mapped
    }

    /**
     * @param value GitHub bring your own app client id.
     */
    @JvmName("txheqvqlqprwfrkw")
    public suspend fun clientId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clientId = mapped
    }

    /**
     * @param value GitHub bring your own app client secret information.
     */
    @JvmName("tmipvqxkqicxrbgs")
    public suspend fun clientSecret(`value`: GitHubClientSecretArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clientSecret = mapped
    }

    /**
     * @param argument GitHub bring your own app client secret information.
     */
    @JvmName("bgifmpvtusvjvmom")
    public suspend fun clientSecret(argument: suspend GitHubClientSecretArgsBuilder.() -> Unit) {
        val toBeMapped = GitHubClientSecretArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.clientSecret = mapped
    }

    /**
     * @param value Collaboration branch.
     */
    @JvmName("wiaxlefbuymeenrp")
    public suspend fun collaborationBranch(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.collaborationBranch = mapped
    }

    /**
     * @param value Disable manual publish operation in ADF studio to favor automated publish.
     */
    @JvmName("ycobjbndqkmycrsg")
    public suspend fun disablePublish(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.disablePublish = mapped
    }

    /**
     * @param value GitHub Enterprise host name. For example: `https://github.mydomain.com`
     */
    @JvmName("eyfpesaanglrjoct")
    public suspend fun hostName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.hostName = mapped
    }

    /**
     * @param value Last commit id.
     */
    @JvmName("tirwgvdvgdwibepl")
    public suspend fun lastCommitId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.lastCommitId = mapped
    }

    /**
     * @param value Repository name.
     */
    @JvmName("yhkqtsybrubiiohl")
    public suspend fun repositoryName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.repositoryName = mapped
    }

    /**
     * @param value Root folder.
     */
    @JvmName("xrckfrfpracaghmp")
    public suspend fun rootFolder(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.rootFolder = mapped
    }

    /**
     * @param value Type of repo configuration.
     * Expected value is 'FactoryGitHubConfiguration'.
     */
    @JvmName("cmblurraojjcdyte")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): FactoryGitHubConfigurationArgs = FactoryGitHubConfigurationArgs(
        accountName = accountName ?: throw PulumiNullFieldException("accountName"),
        clientId = clientId,
        clientSecret = clientSecret,
        collaborationBranch = collaborationBranch ?: throw PulumiNullFieldException("collaborationBranch"),
        disablePublish = disablePublish,
        hostName = hostName,
        lastCommitId = lastCommitId,
        repositoryName = repositoryName ?: throw PulumiNullFieldException("repositoryName"),
        rootFolder = rootFolder ?: throw PulumiNullFieldException("rootFolder"),
        type = type ?: throw PulumiNullFieldException("type"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/FactoryGitHubConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.FactoryGitHubConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Factory's GitHub repo information.
 * @property accountName Account name.
 * @property clientId GitHub bring your own app client id.
 * @property clientSecret GitHub bring your own app client secret information.
 * @property collaborationBranch Collaboration branch.
 * @property disablePublish Disable manual publish operation in ADF studio to favor automated publish.
 * @property hostName GitHub Enterprise host name. For example: `https://github.mydomain.com`
 * @property lastCommitId Last commit id.
 * @property repositoryName Repository name.
 * @property rootFolder Root folder.
 * @property type Type of repo configuration.
 * Expected value is 'FactoryGitHubConfiguration'.
 */
public data class FactoryGitHubConfigurationArgs(
    public val accountName: Output<String>,
    public val clientId: Output<String>? = null,
    public val clientSecret: Output<GitHubClientSecretArgs>? = null,
    public val collaborationBranch: Output<String>,
    public val disablePublish: Output<Boolean>? = null,
    public val hostName: Output<String>? = null,
    public val lastCommitId: Output<String>? = null,
    public val repositoryName: Output<String>,
    public val rootFolder: Output<String>,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.FactoryGitHubConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.FactoryGitHubConfigurationArgs =
        com.pulumi.azurenative.datafactory.inputs.FactoryGitHubConfigurationArgs.builder()
            .accountName(accountName.applyValue({ args0 -> args0 }))
            .clientId(clientId?.applyValue({ args0 -> args0 }))
            .clientSecret(clientSecret?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .collaborationBranch(collaborationBranch.applyValue({ args0 -> args0 }))
            .disablePublish(disablePublish?.applyValue({ args0 -> args0 }))
            .hostName(hostName?.applyValue({ args0 -> args0 }))
            .lastCommitId(lastCommitId?.applyValue({ args0 -> args0 }))
            .repositoryName(repositoryName.applyValue({ args0 -> args0 }))
            .rootFolder(rootFolder.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [FactoryGitHubConfigurationArgs].
 */
@PulumiTagMarker
public class FactoryGitHubConfigurationArgsBuilder internal constructor() {
    private var accountName: Output<String>? = null

    private var clientId: Output<String>? = null

    private var clientSecret: Output<GitHubClientSecretArgs>? = null

    private var collaborationBranch: Output<String>? = null

    private var disablePublish: Output<Boolean>? = null

    private var hostName: Output<String>? = null

    private var lastCommitId: Output<String>? = null

    private var repositoryName: Output<String>? = null

    private var rootFolder: Output<String>? = null

    private var type: Output<String>? = null

    /**
     * @param value Account name.
     */
    @JvmName("yjcqxavfwesmbmwr")
    public suspend fun accountName(`value`: Output<String>) {
        this.accountName = value
    }

    /**
     * @param value GitHub bring your own app client id.
     */
    @JvmName("rqopqemnremkbhog")
    public suspend fun clientId(`value`: Output<String>) {
        this.clientId = value
    }

    /**
     * @param value GitHub bring your own app client secret information.
     */
    @JvmName("ftmkfylhmbyrsfcm")
    public suspend fun clientSecret(`value`: Output<GitHubClientSecretArgs>) {
        this.clientSecret = value
    }

    /**
     * @param value Collaboration branch.
     */
    @JvmName("txxqkbdvpfjkmbyo")
    public suspend fun collaborationBranch(`value`: Output<String>) {
        this.collaborationBranch = value
    }

    /**
     * @param value Disable manual publish operation in ADF studio to favor automated publish.
     */
    @JvmName("reeejpwngwuulccc")
    public suspend fun disablePublish(`value`: Output<Boolean>) {
        this.disablePublish = value
    }

    /**
     * @param value GitHub Enterprise host name. For example: `https://github.mydomain.com`
     */
    @JvmName("sdgxacpgnrksfxpb")
    public suspend fun hostName(`value`: Output<String>) {
        this.hostName = value
    }

    /**
     * @param value Last commit id.
     */
    @JvmName("igsgahycmucvnqlh")
    public suspend fun lastCommitId(`value`: Output<String>) {
        this.lastCommitId = value
    }

    /**
     * @param value Repository name.
     */
    @JvmName("stpffdytckakohid")
    public suspend fun repositoryName(`value`: Output<String>) {
        this.repositoryName = value
    }

    /**
     * @param value Root folder.
     */
    @JvmName("nkqapexnjakabcvm")
    public suspend fun rootFolder(`value`: Output<String>) {
        this.rootFolder = value
    }

    /**
     * @param value Type of repo configuration.
     * Expected value is 'FactoryGitHubConfiguration'.
     */
    @JvmName("obxpqjufqjrknigd")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Account name.
     */
    @JvmName("dtceedgawtiwkfgg")
    public suspend fun accountName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.accountName = mapped
    }

    /**
     * @param value GitHub bring your own app client id.
     */
    @JvmName("vequvbdfsvaypdtl")
    public suspend fun clientId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clientId = mapped
    }

    /**
     * @param value GitHub bring your own app client secret information.
     */
    @JvmName("snijtdjoivinlcfk")
    public suspend fun clientSecret(`value`: GitHubClientSecretArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clientSecret = mapped
    }

    /**
     * @param argument GitHub bring your own app client secret information.
     */
    @JvmName("xtdlqrtmeilngiio")
    public suspend fun clientSecret(argument: suspend GitHubClientSecretArgsBuilder.() -> Unit) {
        val toBeMapped = GitHubClientSecretArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.clientSecret = mapped
    }

    /**
     * @param value Collaboration branch.
     */
    @JvmName("wnrsxcoowmstfyqd")
    public suspend fun collaborationBranch(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.collaborationBranch = mapped
    }

    /**
     * @param value Disable manual publish operation in ADF studio to favor automated publish.
     */
    @JvmName("pscleonmhrnbuvbg")
    public suspend fun disablePublish(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.disablePublish = mapped
    }

    /**
     * @param value GitHub Enterprise host name. For example: `https://github.mydomain.com`
     */
    @JvmName("jfebehpwqocsgiwa")
    public suspend fun hostName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.hostName = mapped
    }

    /**
     * @param value Last commit id.
     */
    @JvmName("hdtrujuypqmxyyov")
    public suspend fun lastCommitId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.lastCommitId = mapped
    }

    /**
     * @param value Repository name.
     */
    @JvmName("jrmlvlptdlagxshq")
    public suspend fun repositoryName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.repositoryName = mapped
    }

    /**
     * @param value Root folder.
     */
    @JvmName("vtnyrjjyhenfulav")
    public suspend fun rootFolder(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.rootFolder = mapped
    }

    /**
     * @param value Type of repo configuration.
     * Expected value is 'FactoryGitHubConfiguration'.
     */
    @JvmName("oinvipwmpymkgydb")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): FactoryGitHubConfigurationArgs = FactoryGitHubConfigurationArgs(
        accountName = accountName ?: throw PulumiNullFieldException("accountName"),
        clientId = clientId,
        clientSecret = clientSecret,
        collaborationBranch = collaborationBranch ?: throw PulumiNullFieldException("collaborationBranch"),
        disablePublish = disablePublish,
        hostName = hostName,
        lastCommitId = lastCommitId,
        repositoryName = repositoryName ?: throw PulumiNullFieldException("repositoryName"),
        rootFolder = rootFolder ?: throw PulumiNullFieldException("rootFolder"),
        type = type ?: throw PulumiNullFieldException("type"),
    )
}
